;*****************************************************************************
;  RC5 Part 3 graphs the delta OBC radiance versus dn.
;
;  Output:
;  1) postscript files containing graphs.
;  
;  v1.0 - 04/02/2008 - Jeff McIntire
;  v2.0 - 03/31/2009 - Jeff McIntire
;   -- Added plots
;*****************************************************************************

PRO RC5_OBC_view, infile

close,/all

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
maxscan=intarr(1)               ; # of scans

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,maxscan
Free_Lun,lun

maxscan=maxscan[0]

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'

;*****************************************************************************
;  Scan average data.
;*****************************************************************************

T_bcs_comp=dblarr(20,2)
ARD_comp=fltarr(20,nbands,nham,maxdet,maxsubsets,2,2)
mean_ARD_comp=fltarr(20,nbands,nham,maxdet,maxsubsets,2,2)
RRU_det_comp=fltarr(20,nbands,nham,maxdet,maxsubsets,2,2)
RRU_comp=fltarr(20,nbands,nham,maxdet,maxsubsets,2,2)

FOR alpha=0, 1 DO BEGIN
    IF alpha EQ 0 THEN restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'
    IF alpha EQ 0 THEN restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
    IF alpha EQ 1 THEN restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.BCS.eff_rad.sav'
    IF alpha EQ 1 THEN restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.BCS.temp.sav'

    FOR col=0, 19 DO BEGIN
        T_bcs_comp[col,alpha]=T_bcs[col]
        
        FOR rsr=0, 1 DO BEGIN
            FOR b=0, nbands-1 DO BEGIN
                FOR is=0, subsets[b]-1 DO BEGIN
                    FOR ih=0, nham-1 DO BEGIN
                        FOR id=0, detectors[b]-1 DO BEGIN
                            ARD_comp[col,b,ih,id,is,rsr,alpha]=ARD[col,b,ih,id,is,1,rsr]
                            IF alpha EQ 0 THEN RRU_det_comp[col,b,ih,id,is,rsr,alpha]=RRU_BCS_det[col,b,ih,id,is,1,rsr]
                            IF alpha EQ 1 THEN RRU_det_comp[col,b,ih,id,is,rsr,alpha]=RRU_det[col,b,ih,id,is,1,0,rsr]
                        ENDFOR
                        mean_ARD_comp[col,b,ih,is,rsr,alpha]=mean_ARD[col,b,ih,is,1,rsr]
                        IF alpha EQ 0 THEN RRU_comp[col,b,ih,is,rsr,alpha]=RRU_BCS[col,b,ih,is,1,rsr]
                        IF alpha EQ 1 THEN RRU_comp[col,b,ih,is,rsr,alpha]=RRU[col,b,ih,is,1,0,rsr]
                    ENDFOR
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Some definitions.
;*****************************************************************************

mindet=[0,0,0,0,1,0,0,0]

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)
HAM=['A','B']
SS=[' SS1',' SS2']
HAM_SS=['HAM A, SS1','HAM B, SS1','HAM A, SS2','HAM B, SS2'] 

;*****************************************************************************
;  Plot the BCS ARD in a .ps file.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard.bcs.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

;*****************************************************************************
;  Plot the ARD per detector.
;*****************************************************************************

title1='BCS Absolute Radiance Difference, (SRV0545-6)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' HAM A (quadratic poly_fit)'

    collects=WHERE(T_bcs_comp[*,1] GT 235.)
    xcollect=WHERE(ARD_comp[*,b,0,8,0,0,0] NE 0)
    ymax=max(ARD_comp[collects,b,0,mindet[b]:detectors[b]-1,0,0,1],min=ymin)

    plot,T_bcs_comp[collects,1],ARD_comp[collects,b,0,8,0,0,1],xtit='BCS Temperature (K)',ytit='BCS ARD',yrange=[ymin,ymax], $
      xrange=[250,350],title=title2,charsize=1.2,charthick=5,thick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_bcs_comp[collects,1],ARD_comp[collects,b,0,id,0,0,1],symsize=1,color=lcol[id],psym=symbol[id],thick=5
        oplot,T_bcs_comp[collects,1],ARD_comp[collects,b,0,id,0,0,1],color=lcol[id],thick=5

        oplot,T_bcs_comp[xcollect,0],ARD_comp[xcollect,b,0,id,0,0,0],symsize=2,color=lcol[id],psym=symbol[id],thick=5
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the mean ARD.
;*****************************************************************************

title1='BCS Absolute Radiance Difference, (SRV0545-6)'
plot,T_bcs_comp[collects,1],mean_ARD_comp[collects,0,0,0,0,1],xtit='BCS Temperature (K)',ytit='BCS ARD',yrange=[-1,1], $
  xrange=[250,350],charsize=1.2,charthick=5,thick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_bcs_comp[collects,1],mean_ARD_comp[collects,b,0,0,0,1],symsize=1,color=lcol[b],psym=symbol[b],thick=5
    oplot,T_bcs_comp[collects,1],mean_ARD_comp[collects,b,0,0,0,1],color=lcol[b],thick=5

    oplot,T_bcs_comp[xcollect,0],mean_ARD_comp[xcollect,b,0,0,0,0],symsize=2,color=lcol[b],psym=symbol[b],thick=5
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

device,/close

;*****************************************************************************
;  Plot the OBC RRU in a .ps file.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru.bcs.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

;*****************************************************************************
;  Plot the RRU per detector.
;*****************************************************************************

title1='BCS Absolute Radiance Difference, (SRV0545-6)'
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' HAM A (quadratic poly_fit)'

    collects=WHERE(T_bcs_comp[*,1] GT 235.)
    xcollect=WHERE(RRU_det_comp[*,b,0,8,0,0,0] NE 0)

    plot,T_bcs_comp[collects,1],RRU_det_comp[collects,b,0,8,0,0,1],xtit='BCS Temperature (K)',ytit='BCS RRU',yrange=[0,1.1], $
      xrange=[250,350],title=title2,charsize=1.2,charthick=5,thick=5,/nodata

    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_bcs_comp[collects,1],RRU_det_comp[collects,b,0,id,0,0,1],symsize=1,color=lcol[id],psym=symbol[id],thick=5
        oplot,T_bcs_comp[collects,1],RRU_det_comp[collects,b,0,id,0,0,1],color=lcol[id],thick=5

        oplot,T_bcs_comp[xcollect,0],RRU_det_comp[xcollect,b,0,id,0,0,0],symsize=2,color=lcol[id],psym=symbol[id],thick=5
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

;*****************************************************************************
;  Plot the mean RRU.
;*****************************************************************************

title1='BCS Absolute Radiance Difference, (SRV0545-6)'
plot,T_bcs_comp[collects,1],RRU_comp[collects,0,0,0,0,1],xtit='BCS Temperature (K)',ytit='BCS RRU',yrange=[0,1.1], $
  xrange=[250,350],charsize=1.2,charthick=5,thick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_bcs_comp[collects,1],RRU_comp[collects,b,0,0,0,1],symsize=1,color=lcol[b],psym=symbol[b],thick=5
    oplot,T_bcs_comp[collects,1],RRU_comp[collects,b,0,0,0,1],color=lcol[b],thick=5

    oplot,T_bcs_comp[xcollect,0],RRU_comp[xcollect,b,0,0,0,0],symsize=2,color=lcol[b],psym=symbol[b],thick=5
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

device,/close

END
